<div align="center">
<picture>
  <source media="(prefers-color-scheme: dark)" srcset="docs/theme/assets/napse_invest_logo_white.svg">
  <source media="(prefers-color-scheme: light)" srcset="docs/theme/assets/napse_invest_logo_black.svg">
  <img alt="Napse's logo" src="" width=500>
</picture>
</div>

<br>

<p align="center">
  <a href="https://twitter.com/NapseInvest">
    <img src="https://img.shields.io/twitter/follow/NapseInvest?style=flat&label=%40NapseInvest&logo=twitter&color=0bf&logoColor=fff" alt="Twitter" />
  </a>
  <a>
    <img src="https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/napse-investment/40fac957532fe3b731c99067467de842/raw/django-napse-coverage.json" alt="Coverage" />
  </a>
  <a>  
    <img src="https://img.shields.io/github/v/release/napse-invest/django-napse" alt="Release" />
  </a>
</p>

<p align="center">
  <a href="#django-napse"><strong>Django Napse</strong></a> ·
  <a href="#documentation"><strong>Documentation</strong></a> .
  <a href="#how-to-contribute"><strong>How to contribute</strong></a>
</p>
<br/>

## django-napse

Django napse is a portfolio management module using trading bots.
This directory can be used as a django module, which you can install as follows:

```bash
pip install django-napse
```

Or you can use it as a local backend for the [Napse desktop application](https://github.com/napse-invest/Napse), by cloning the repository.

Find more details for installation in the [documentation](https://napse-invest.github.io/django-napse/#installation).

### Quick start

```shell
make setup
make up
```

### Documentation

You can find the documentation [here](https://napse-invest.github.io/django-napse/).


## How to contribute

If you want to contribute to the project, please read the [contributing guidelines](https://napse-invest.github.io/django-napse/contributing/) first. You will find the setup instructions and our standards.

